#!/usr/bin/sh
# Ĉi tiu skripto densigos ĉiujn bildosignojn, kaj movos ilin al eliga dosierujo.
# Ĉiu bildosignaro iom perdos kvaliton; la intenseco de tiu perdo varias laŭ
# specialaj konsideroj, kiujn vi povas legi pli sube, kie vi ankaŭ povas ŝanĝi
# la kvalitan perdon laŭ viaj propraj deziroj kaj bezonoj.

# Certigu, ke eliga dosierujo ekzistas.
out_dir="$1";
arc_dir="$2";
if test -z "$out_dir"; then
	echo "Uzmaniero: $(basename "$0") ELIGUJO ARĤIVUJO"
	exit 1
elif test -z "$arc_dir"; then
	echo "Uzmaniero: $(basename "$0") ELIGUJO ARĤIVUJO"
	exit 2
fi
mkdir -p "$out_dir";
mkdir -p "$arc_dir";

# optimise [min] [max] [dosierujoj] …
# Elkopias kaj densigas ĉiujn PNG-bildojn en ĉiu el la dosierujoj.
# Densigo okazas perde, en kvaliteca intervalo inter 0–100, donita en min/max.
# Bonvolu vidi la dokumentaĵon de pngquant por pli da informoj.
optimise () {
	min="$1"; shift
	max="$1"; shift
	for dir in "$@"; do
		echo "MIN: $min | MAX: $max | DIR: $dir"
		echo "---------------------------------------------"
		# Kopiu ĉiun dosierujon.
		cp --parents -rt "$out_dir" "$dir"
		# Densigu kopiojn de ĉiuj dosieroj.
		for file in "$out_dir/$dir"/*.png; do
			pngquant \
				--output "$file" --quality "$min"-"$max" \
				--speed 1 --force --strip \
				"$file"
			zopflipng \
				--iterations=32 --filters=0me \
				--lossy_transparent -y \
				"$file" "$file"
		done
	done
}

# archive [dosierujoj] …
# Pakas densigitajn bildosignarojn en arĥivon, kune kun »pack.json«.
# Voku ĉi tiun funkcion post la funkcio »optimise«, kun radika eniga
# dosierujo kiel parametro.
archive() {
	for dir in "$@"; do
		arc=$(basename "$dir")
		arc_dir=$(realpath "$arc_dir")
		echo "… ARĤIVADO DE $arc  …"
		(cd $out_dir && zip -9r "$arc_dir/$arc.zip" "$dir"/*.png "$dir"/*.gif "$dir"/.prio.md "$dir"/pack.json)
		echo "---------------------------------------------"
	done
}


# flatten [dosierujoj]
# Platigas eligan dosierujon de bildosignoj; t.e., ĝi movas ĉion de
# subdosierujoj al la radikan dosierujon de la bildosignaro.
#    eligo/bildosignaro/subdosierujo/A.png → eligo/bildosignaro/A.png
flatten() {
	for dir in "$@"; do
		(cd $out_dir; mv "$dir"/*/* "$dir"; rmdir "$dir"/*/)
	done
}


# Anseroj - Ne devas tre atenti detalojn.
optimise 60 80 "Anseroj"
archive "Anseroj"

# Astroj - Ne devas tre atenti detalojn.
optimise 60 80 "Astroj"
archive "Astroj"

# Babilado - Povas iom gravi detaloj.
optimise 80 90 "Babilado"
archive "Babilado"

# Bitludoj – Povus iom gravi detaloj.
optimise 80 90 "Bitludoj malliberaj"
archive "Bitludoj malliberaj"

# Etikedoj – Iuj povus havi gravajn etajn detalojn.
optimise 90 95 "Etikedoj"
archive "Etikedoj"

# Filmoj – Preskaŭ temas pri fotoj.
optimise 40 60 "Filmoj"
archive "Filmoj"

# Flagoj – Iuj havas gravajn etajn detalojn.
optimise 90 95 "Flagoj"/*
archive "Flagoj"
flatten "Flagoj"

# Gutkatoj – Ne devas tre atenti detalojn.
optimise 60 80 "Gutkatoj"
cp -rt "$out_dir/Gutkatoj" "Gutkatoj/movbildoj"
archive "Gutkatoj"

# Haiku – Ili apenaŭ densiĝas, kaj la artstilo postulas kvalitecon.
optimise 90 95 "Haiku"
archive "Haiku"

# Laborado!! – Gravas la detaloj tie ĉi.
optimise 90 95 "Laborado!!"
archive "Laborado!!"

# Madoka - Ne devas tre atenti detalojn.
optimise 70 80 "Madoka Maĝika"
archive "Madoka Maĝika"

# Manĝaĵoj – Ne devas tre atenti detalojn.
optimise 60 80 "Manĝaĵoj"
archive "Manĝaĵoj"

# Moneroj – Ili estas fotoj. Tre densigu!
optimise 30 40 "Moneroj"/*
archive "Moneroj"
flatten "Moneroj"

# Programaroj – Koloraj transiroj.
optimise 80 90 "Programaro libera" "Programaro mezlibera"
archive "Programaro libera" "Programaro mezlibera"

# Spiono×Familio - Ne devas tre atenti detalojn.
optimise 70 80 "Spiono×Familio"
archive "Spiono×Familio"
flatten "Spiono×Familio"

# Testoj – Ne devas tre atenti detalojn.
optimise 60 80 "Testing"
archive "Testing"

