#!/bin/sh
# Nomo: bildosignaroj.sh
# Pri: Ĉi tiu skripto kreos HTML-liston de bildosigaroj.
# Dato: 2024-03-18

# Per dosierujo-vojo de bildosignaro, presas HTML-alineon priskriban.
htmligi_bildosignaro() {
	local bildosignarujo="$1"
	local id="$(bildosignaro_id "$bildosignarujo")"

	echo "<section id='${id}'>"
	bildosignaro_html_kapo "$bildosignarujo"
	bildosignaro_html_korpo "$bildosignarujo"
	echo "</section>"

}


# Presas la HTMLan alineokapon de bildosignaro ĉe la donita dosierujovojo.
bildosignaro_html_kapo() {
	local bildosignarujo="$1"
	local nomo="$(basename "$bildosignarujo")"
	local bildo="$(basename "$(bildosignaro_ekzemplero "$bildosignarujo")")"
	cat <<EOF
	<h3>
		${nomo}
		<img height=40px src="/emoji/${nomo}/${bildo}">
		<a class="button-default loadmore-button download-button"
		   href="https://jam.xwx.moe/emoji/${nomo}.zip">
			Elŝuti
		</a>
	</h3>
EOF
}


# Presas la HTMLan alineoenhavon de bildosignaro ĉe la donita dosierujovojo.
bildosignaro_html_korpo() {
	local bildosignarujo="$1"
	tail +2 "${bildosignarujo}/.prio.md" \
		| md2html \
		| sed 's/h5>/h7>/g' \
		| sed 's/h4>/h6>/g' \
		| sed 's/h3>/h5>/g' \
		| sed 's/h2>/h4>/g' \
		| sed 's/h1>/h3>/g'
}


# Liveras identiigan tekstoĉenon simplan, per nomo de bildosignaro, kiu taŭgas
# por uzo ĉe ligiloj ktp.
bildosignaro_id() {
	local bildosignaro="$1"
	basename "$bildosignaro" \
		| tr ' ' '_' \
		| awk '{ print tolower($0) }'
}


# Presas la relativan vojon al ekzempla bildo de bildosignaro, prenita
# de ĝia `.prio.md`.
bildosignaro_ekzemplero() {
	local bildosignarujo="$1"
	head -1 "$bildosignarujo/.prio.md" \
		| sed 's/.*(//' \
		| sed 's/).*//'
}


uzado() {
	echo "uzado: $(basename $0) BILDOSIGNAROJ_DOSIERUJO"
	echo ""
	echo "Presas liston de bildosignaroj en la donita dosierujo."
	echo "Bildosignaraj dosierujoj havu dosierno «.prio.md», kiu"
	echo "enhavu Markdown-forman priskribon de la bildosignaro."
}


BILDOSIGNARARUJO="$1" # Tordas la langon, ĉu ne? xP

if test -z "$1"; then
	uzado 1>&2
	exit 2
elif test "$1" = "-h" -o "$1" = "--help" -o "$1" = "-?"; then
	uzado
	exit 0
fi


# Presu la paĝkapon…
cat bildosignaroj.sh.html

# … kaj poste la listerojn.
for bildosignarujo in "$BILDOSIGNARARUJO"/*/; do
	if test -f "$bildosignarujo/.prio.md"; then
		htmligi_bildosignaro "$bildosignarujo"
		printf '\n\n'
	else
		echo "$bildosignarujo havas ne dosieron .prio.md!" 1>&2
		echo "Ne listigos ĝin." 1>&2
	fi
done
